#!/bin/sh
#
# @file gen-obex-capability.sh 
# This script generates capability object to be used by obexd daemon
#
# Copyright (C) 2008 Nokia Corporation. All rights reserved.
#
# Contact: Biris Ilias <ilias.biris@nokia.com>
#
# This software, including documentation, is protected by copyright
# controlled by Nokia Corporation. All rights are reserved. Copying,
# including reproducing, storing, adapting or translating, any or all
# of this material requires the prior written consent of Nokia Corporation.
# This material also contains confidential information which may not be
# disclosed to others without the prior written consent of Nokia.
#

MSYNC_DIR="/home/user/.sync"
IMEI_FILE="$MSYNC_DIR/.imei"
OSSO_VER="/tmp/osso_software_version"
MMC_DIR="/media/mmc1"
# TODO : remove the below MYDOCSDIR  once the env variables are properly set on
# HARMATTAN
MYDOCSDIR="/home/user/MyDocs"
CAPABILITY_FILE="$MYDOCSDIR/capability.xml"
TMP_CAPABILITY_FILE="/tmp/msync-capability.xml"
OBEX_ROOT=/home/user/.obex-root
SUITECONF_FILE="$MYDOCSDIR/.SuiteConf.xml"
INSTALLED_SUITECONF_FILE="/etc/sync/xml/SuiteConf.xml"
REV_DATE="20100301T000000Z"

# get_capability function
# param None
# This function generates capability object
get_capability()
{
cat << END	
<?xml version="1.0" ?>
<!-- OBEX Capability Object -->
<!DOCTYPE Capability SYSTEM "obex-capability.dtd">
<Capability Version="1.0">
    <General>
        <Manufacturer>Nokia</Manufacturer>
        <Model>$PRODUCT</Model>
        <SN>$IMEI_NO</SN>
        <SW Version="$VERSION" Date="$REV_DATE"/>
        <Language>en</Language>
        <Memory>
            <MemType>DEV</MemType>
            <Location>$MYDOCSDIR</Location>
            <Free>$DEVM_FREE</Free>
            <Used>$DEVM_USED</Used>
            <FileNLen>256</FileNLen>
        </Memory>
        <Memory>
            <MemType>MMC</MemType>
            <Location>$MMC_DIR</Location>
            <Free>$MMC_FREE</Free>
            <Used>$MMC_USED</Used>
            <FileNLen>256</FileNLen>
        </Memory>
        <Ext>
            <XNam>NetworkInfo</XNam>
            <XVal>CurrentNetwork=$OPERATOR_NAME</XVal>
            <XVal>CountryCode=$OPERATOR_COUNTRY_CODE</XVal>
            <XVal>NetworkID=$NETWORK_ID</XVal>
        </Ext>
        <Ext>
            <XNam>ModelName</XNam>
            <XVal>unknown</XVal>
        </Ext>
        <Ext>
            <XNam>ProductCode</XNam>
            <XVal>$PRODUCT_CODE</XVal>
        </Ext>
    </General>
    <Service>
        <Name>SyncML</Name>
        <UUID>SYNCML-SYNC</UUID>
        <Version>1.2</Version>
        <Object>
            <Type>application/vnd.syncml+wbxml</Type>
        
            <Ext>
                <XNam>ServerAlertedNotificationType</XNam>
                <XVal>application/vnd.syncml.ds.notification</XVal>
            </Ext>
        </Object>
    </Service>
    <Service>
    <Name>SyncMLD2D</Name>
    <UUID>00005601-0000-1000-8000-0002EE000001</UUID>
    <Version>1.1</Version>                           
    <Object>                                         
      <Type>application/vnd.syncml+wbxml</Type>      
      <Ext>                                          
        <XNam>MIME</XNam>                            
        <XVal>text/x-vcalendar</XVal>                
      </Ext>
      <!-- bookmark sync is not supported in harmattan 1.0 -->
      <!--
      <Ext>                                          
        <XNam>MIME</XNam>                            
        <XVal>text/x-vbookmark</XVal>                
      </Ext>
      -->
      <Ext>                                          
        <XNam>MIME</XNam>                            
        <XVal>text/x-vcard</XVal>                    
      </Ext>                                         
      <Ext>                                                
        <XNam>MIME</XNam>                                  
        <XVal>text/plain</XVal>                            
      </Ext>
      <Ext>                                                
        <XNam>MIME</XNam>                                  
        <XVal>text/x-vmsg</XVal>                           
      </Ext>                                                     
    </Object>                                              
  </Service>                                   


    <Service>
        <Name>PCCS</Name>
        <UUID>F9EC7BC4-953c-11d2-984E-525400DC9E09</UUID>
        <Version>1.6</Version>
    </Service>
    <Service>
        <Name>PCSuite-Settings</Name>
        <Version>1.0</Version>
        <Ext>
            <XNam>SuiteConf</XNam>
            <XVal>File=.SuiteConf.xml</XVal>
        </Ext>
    </Service>
    <!-- bookmark sync is not supported in harmattan 1.0 -->
    <!--
    <Service>
        <Name>Bookmarks</Name>
        <UUID>SYNCML-SYNC</UUID>
        <Version>1003.6</Version>
        <Object>
            <Type>text/x-vbookmark</Type>
            <Name-Ext>bookmarks</Name-Ext>
        </Object>
        <Ext>
            <XNam>SyncProfile</XNam>
            <XVal>HostAddress=PC Suite Data Sync</XVal>
            <XVal>Database=bookmarks</XVal>
        </Ext>
    </Service>
    -->

    <Service>
        <Name>Folder-Browsing</Name>
        <UUID>F9EC7BC4-953c-11d2-984E-525400DC9E09</UUID>
        <Version>1.3</Version>
        <Object>
            <Type>x-obex/folder-listing</Type>
        </Object>
        <Ext>
            <XNam>Images</XNam>
            <XVal>Folder=Data\</XVal>
            <XVal>MemType=DEV</XVal>
        </Ext>
        <Ext>
            <XNam>Videos</XNam>
            <XVal>Folder=Data\</XVal>
            <XVal>MemType=DEV</XVal>
        </Ext>
        <Ext>
            <XNam>Music</XNam>
            <XVal>Folder=Data\</XVal>
            <XVal>MemType=DEV</XVal>
        </Ext>
        <Ext>
            <XNam>Graphics</XNam>
            <XVal>Folder=Data\</XVal>
            <XVal>MemType=DEV</XVal>
        </Ext>
    </Service>
    
    <Service>
       <Name>Text Messages</Name>
       <UUID>SYNCML-SYNC</UUID>
       <Version>1002.2</Version>
       <Object>
         <Type>text/x-vMessage</Type>
         <Name-Ext>sms</Name-Ext>
       </Object>
       <Ext>
         <XNam>SyncProfile</XNam>
         <XVal>HostAddress=PC Suite Data Sync</XVal>
         <XVal>Database=sms</XVal>
       </Ext>
       <Ext>
         <XNam>Databases</XNam>
         <XVal>Drafts=4100</XVal>
         <XVal>Inbox=4098</XVal>
         <XVal>Outbox=4099</XVal>
         <XVal>SentItems=4101</XVal>
       </Ext>
    </Service>

    <Service>                                                                   
        <Name>Backup</Name>                                                     
        <UUID>F9EC7BC4-953c-11d2-984E-525400DC9E09</UUID>                       
        <Version>1.0</Version>                                                  
        <Object>                                                                
                <Type>application/vnd.nokia-backup</Type>                       
        </Object>                                                               
        <Ext>                                                                   
                <XNam>BackupSettings</XNam>                                     
                <XVal>Backup-Start=100</XVal>                                   
                <XVal>Backup-Stop=101</XVal>                                    
                <XVal>Restore-Start=200</XVal>                                  
                <XVal>Restore-Stop=201</XVal>                                   
        </Ext>                                                                  
        <Ext>                                                                   
                <XNam>BackupContent</XNam>                                      
                <XVal>Contacts=1</XVal>                                         
                <XVal>Calendar=2</XVal>                                         
                <XVal>Messages=3</XVal>
                <!-- bookmark sync is not supported in harmattan 1.0 -->
                <!--
                <XVal>Bookmarks=4</XVal>                                        
                -->
                <XVal>Settings=4</XVal>
                <XVal>Applications=5</XVal>
        </Ext>                                                                  
    </Service> 

</Capability>
END
}

# Function to initialize following variables IMEI, VERSION, FREE, USED
#param None
#return None
init_values()
{
        source /tmp/session_bus_address.user 

######################Get Product Name#####################################
	PRODUCT_NAME=`sysinfoclient -p /component/product-name`
	if test -z "$PRODUCT_NAME"
	then
	    PRODUCT_NAME="Nxxx/RM-680"
	fi	    
######################Get IMEI No #####################################

        if [ -f $IMEI_FILE ] ; 
        then
           IMEI_NO=`cat $IMEI_FILE`
        else 
           IMEI_NO=`sysinfoclient  -p /certs/npc/esn/gsm`
        fi 

	if test -z "$IMEI_NO"
	then
	    IMEI_NO=000001111111111
        else 
            echo $IMEI_NO > $IMEI_FILE
	fi


######################Get OSSO Version Info #####################################

        
	VERSION="V `sysinfoclient -p /device/sw-release-ver | cut -d'_' -f3-` $PRODUCT_NAME"
            
	if test -z "$VERSION" ;
        then
	    VERSION="V `echo $OSSO_VERSION | cut -d'=' -f2 | cut -d'_' -f3-` $PRODUCT_NAME"
	fi


######################Get Product Code #####################################

	PRODUCT_CODE=`sysinfoclient -p /device/product-code`


######################Get Product #####################################

	PRODUCT=$(sysinfoclient -p /component/product)

######################Get Device Memory Information #####################################

	df_out=`df -k`
	DEVM_USED_K=`echo "$df_out" | awk -v d="$MYDOCSDIR" 'NR > 1 && $6 == d { print $3;}'`
	DEVM_FREE_K=`echo "$df_out" | awk -v d="$MYDOCSDIR" 'NR > 1 && $6 == d { print $4;}'`
	MMC_USED_K=`echo "$df_out" | awk -v d="$MMC_DIR" 'NR > 1 && $6 == d { print $3;}'`
	MMC_FREE_K=`echo "$df_out" | awk -v d="$MMC_DIR" 'NR > 1 && $6 == d { print $4;}'`

        #using perl to multiply to bytes
        #multiplication has to support large numbers
	if test -n "$DEVM_USED_K"
	then
	    DEVM_USED=`perl -e "print 1024*$DEVM_USED_K"`
	fi
	if test -n "$DEVM_FREE_K"
	then
	    DEVM_FREE=`perl -e "print 1024*$DEVM_FREE_K"`
	fi
	if test -n "$MMC_USED_K"
	then
	    MMC_USED=`perl -e "print 1024*$MMC_USED_K"`
	fi
	if test -n "$MMC_FREE_K"
	then
	    MMC_FREE=`perl -e "print 1024*$MMC_FREE_K"`
	fi

######################Get Operator Information #####################################

# temporarily disabling the dbus calls that are not yet supported on harmattan 
# this is done to random crashes  observed while generating the CO 

	OPERATOR_NAME=`dbus-send --system --print-reply --dest=com.nokia.csd.CSNet /com/nokia/csd/csnet org.freedesktop.DBus.Properties.Get string:com.nokia.csd.CSNet.NetworkOperator string:OperatorName | grep string | cut -d'"' -f2 | cut -d'(' -f2 | cut -d')' -f1`
	OPERATOR_COUNTRY_CODE=`dbus-send --system --print-reply --dest=com.nokia.csd.CSNet /com/nokia/csd/csnet org.freedesktop.DBus.Properties.Get string:com.nokia.csd.CSNet.NetworkOperator string:OperatorMCC | grep string | cut -d'"' -f2`
	NETWORK_ID=`dbus-send --system --print-reply --dest=com.nokia.csd.CSNet /com/nokia/csd/csnet org.freedesktop.DBus.Properties.Get string:com.nokia.csd.CSNet.NetworkOperator string:OperatorMNC | grep string | cut -d'"' -f2`
}

# Function to check if file has changed and if yes then update the same
#param None
#return None
check_capability_file_diff()
{
init_values
get_capability | tee  $TMP_CAPABILITY_FILE
cmp -s "$TMP_CAPABILITY_FILE" "$CAPABILITY_FILE"
if [ $? -ne 0 ] ; then
    chmod 755 $MYDOCSDIR
	cp "$TMP_CAPABILITY_FILE" "$CAPABILITY_FILE".new &&
	mv "$CAPABILITY_FILE".new "$CAPABILITY_FILE" &&
	rm "$TMP_CAPABILITY_FILE"
fi	
}

check_suiteconf_file_diff()
{
cmp -s "$INSTALLED_SUITECONF_FILE" "$SUITECONF_FILE"
if [ $? -ne 0 ] ; then
	cp "$INSTALLED_SUITECONF_FILE" "$SUITECONF_FILE".new &&
	mv "$SUITECONF_FILE".new "$SUITECONF_FILE" 
fi	
}

#check cached capability file already exists or not
if [ -f "$CAPABILITY_FILE" ]; then
        check_capability_file_diff 
else
        if [ ! -d "$MSYNC_DIR" ]; 
        then 
	mkdir -p "$MSYNC_DIR" 
        fi
        chmod 755 $MYDOCSDIR
	init_values
	get_capability | tee $TMP_CAPABILITY_FILE
	cp "$TMP_CAPABILITY_FILE" "$CAPABILITY_FILE".new &&
	mv "$CAPABILITY_FILE".new "$CAPABILITY_FILE" &&
	rm "$TMP_CAPABILITY_FILE"
fi

if [  -f "$SUITECONF_FILE" ]; then
	check_suiteconf_file_diff
else
	cp "$INSTALLED_SUITECONF_FILE" "$SUITECONF_FILE".new &&
	mv "$SUITECONF_FILE".new "$SUITECONF_FILE" 
fi

exit 0



